import 'package:device_info_plus/device_info_plus.dart';
import 'package:rdc_flutter_sdk/src/util/advertising_helper.dart';

class DeviceInfoController {
  var osType = '';
  var osVersion = '';

  var globalId = '';

  var device = '';
  var model = '';
  var brandName = '';
  var board = '';
  var display = '';

  var maId = '';

  Future<DeviceInfoController> init() async {
    await _getDeviceInfo();
    await _getAdvertising();
    return this;
  }

  Future<void> _getDeviceInfo() async {
    try {
      var deviceInfoPlugin = DeviceInfoPlugin();
      var deviceInfo = await deviceInfoPlugin.deviceInfo;
      if (deviceInfo is AndroidDeviceInfo) {
        globalId = deviceInfo.id ?? '';
        osType = deviceInfo.version.release ?? '';
        osVersion = (deviceInfo.version.sdkInt ?? 0).toString();
        device = deviceInfo.device ?? '';
        model = deviceInfo.model ?? '';
        brandName = deviceInfo.brand ?? '';
        board = deviceInfo.board ?? '';
        display = deviceInfo.display ?? '';
      } else if (deviceInfo is IosDeviceInfo) {
        globalId = deviceInfo.identifierForVendor ?? '';
        osType = deviceInfo.systemName ?? '';
        osVersion = deviceInfo.systemVersion ?? '';
        device = deviceInfo.name ?? '';
        model = deviceInfo.model ?? '';
      }
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> _getAdvertising() async {
    try {
      maId = await AdvertisingHelper.getAdvertisingId();
    } catch (e) {
      print(e.toString());
    }
  }
}
