import 'package:get/get.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:rdc_flutter_sdk/src/model/version.dart';
import 'package:rdc_flutter_sdk/src/repositories/version_repo.dart';
import 'package:rdc_flutter_sdk/src/util/file_helper.dart';

class VersionController {
  final _versionRepo = VersionRepo();
  var appVer = '';
  var appVerNum = '';
  var prevAppVer = '';
  var prevAppVerNum = '';
  var sdkVersion = '';

  Future<VersionController> init() async {
    await _init();
    await _hasData();
    return this;
  }

  Future<void> _init() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    appVer = packageInfo.version;
    appVerNum = packageInfo.buildNumber;
    sdkVersion = await FileHelper.getVersion();
  }

  Future<void> _hasData() async {
    var data = await _versionRepo.getAll();

    // check first run app
    if (data.isEmpty) {
      prevAppVer = appVer;
      prevAppVerNum = appVerNum;
      await save();
      return;
    }

    var version = data[0];
    // new version app
    if (version.appVer != appVer) {
      prevAppVer = version.appVer;
      prevAppVerNum = version.appVerNum;
      await save();
    } else {
      prevAppVer = version.prevAppVer;
      prevAppVerNum = version.prevAppVerNum;
    }
  }

  Future<void> save() async {
    await _versionRepo.deleteAll();
    await _versionRepo.insert(Version()
      ..appVer = appVer
      ..appVerNum = appVerNum
      ..prevAppVer = prevAppVer
      ..prevAppVerNum = prevAppVerNum);
  }
}
