import 'package:get/get_state_manager/get_state_manager.dart';
import 'package:hive/hive.dart';
import 'package:rdc_flutter_sdk/src/database/db_interface.dart';
import 'package:rdc_flutter_sdk/src/model/hive_config.dart';

class HiveDBImpl extends GetxController implements HiveDBInterface {
  late HiveConfig _config;

  HiveDBImpl(HiveConfig config) {
    assert(config.dbName.isNotEmpty);
    _config = config;
  }

  @override
  Future<Box<T>> hiveBox<T>(String boxName) async {
    return await Hive.openBox<T>(boxName,
        path: _config.path, encryptionCipher: _config.cipher);
  }

  @override
  Future<Map<int, T>> getAll<T>(String boxName) async {
    assert(boxName.isNotEmpty);

    var box = await hiveBox<T>(boxName);

    Map<int, T> results = {};
    for (var key in box.keys) {
      results[key] = box.get(key) as T;
    }
    return results;
  }

  @override
  Future<Map<int, T?>> get<T>(String boxName, int key) async {
    assert(boxName.isNotEmpty);

    var box = await hiveBox<T>(boxName);
    var result = box.get(key);
    return <int, T?>{key: result};
  }

  @override
  Future<void> insert<T>(String boxName, T data) async {
    assert(boxName.isNotEmpty);
    assert(data != null);

    var box = await hiveBox<T>(boxName);
    await box.add(data);
  }

  @override
  Future<void> upsert<T>(String boxName, int key, T data) async {
    assert(boxName.isNotEmpty);
    assert(data != null);

    var box = await hiveBox<T>(boxName);
    await box.put(key, data);
  }

  @override
  Future<void> delete<T>(String boxName, int key) async {
    assert(boxName.isNotEmpty);

    var box = await hiveBox<T>(boxName);
    await box.delete(key);
  }

  @override
  Future<void> deleteKeys<T>(String boxName, List<int> keys) async {
    assert(boxName.isNotEmpty);

    var box = await hiveBox<T>(boxName);
    await box.deleteAll(keys);
  }

  @override
  Future<void> deleteAll<T>(String boxName) async {
    assert(boxName.isNotEmpty);

    var box = await hiveBox<T>(boxName);
    await box.clear();
  }
}
